@@ -37,3 +37,15 @@ class NameField(forms.CharField):
             excludeforbidden
         ])
         super().__init__(*args, **kwargs)
+
+
+class PrincipalField(forms.CharField):
+    """A :class:`~django.forms.CharField` that ensures that a :term:`Principal`
+    is always lowercase.
+    """
+
+    def clean(self, value):
+        """Invokes :meth:`django.forms.Charfield.clean()` and lowercases the
+        value.
+        """
+        return str.lower(super().clean(value))
