@@ -3,7 +3,6 @@ from django.urls import include
 from django.urls import path
 from django.conf import settings
 from django.contrib.auth.decorators import login_required
-from django.contrib.auth.views import LogoutView
 from django.views.generic import TemplateView
 from django.utils.translation import gettext_lazy as _
 
@@ -32,7 +31,7 @@ urlpatterns.extend([
     path(_('login/'), views.LoginView.as_view(allow_public=True), name='login'),
     path(_('login/magic'), views.MagicLinkView.as_view(), name='login.magic'),
     path(_('login/token'), views.LoginTokenView.as_view(), name='login.token'),
-    path(_('logout'), LogoutView.as_view(), name='logout'),
+    path(_('logout'), views.LogoutView.as_view(), name='logout'),
     path(_('register'), views.RegisterView.as_view(), name='register'),
 ])
 
